# v0.7.0

- Change the dependencies for Rust packages

# v0.6.5

- Change the algorithm to create RPN

# v0.6.4

- Add ite for BddNode/MddNode

# v0.6.3

- Chage the interface to compute the probability for MSS

# v0.6.1-0.6.2

- Add get_varorder for BSS

# v0.6.0

- Change the method 'extranct' as an Iterator in BSS

# v0.5.2

- Add b-measure for BDD

# v0.5.1

- Python 3.10 support

# v0.5.0

- Change interface

# v0.4.4

- add aarch64 support

# v0.4.3

- Add the function to calculate the prob for Bool-type MDD

# v0.4.1

- Bug fix: the bug of without 

# v0.4.0

- Add the function to draw the MDD

# v0.3.0

- First release

# v0.2.0

- change to use python codes to reduce the complexity
- change the interface for FT and MSS
- add MSS for the first time

# v0.1.0-0.1.1

- old version
